@@ -2,6 +2,7 @@ import click
 import os
 import sys
 import jinja2
+import toml
 
 from ppc.python_project_creator import PythonProjectCreator
 
@@ -13,10 +14,11 @@ def main():
 
 @main.command()
 @click.option("-t", "--template", help="Template to use.")
+@click.option("-c", "--config", help="TOML file with config.")
 @click.argument("output")
-def create(template, output):
+def create(template, config, output):
     """Create a python project based on a template.
-    
+
     Currently the following templates are supported:
 
     * basic
@@ -35,8 +37,14 @@ def create(template, output):
 
     click.echo(f"Creating project with template {template} at {output}")
 
+    project_model = None
+    if config:
+        with open(config) as file:
+            project_model = toml.loads(file.read())
+            click.echo("Using config file...")
+
     try:
-        creator = PythonProjectCreator(model=None, template=template)
+        creator = PythonProjectCreator(model=project_model, template=template)
         creator.create(output)
         click.echo("Project created :)")
     except jinja2.exceptions.UndefinedError as e:
